@@ -25,7 +25,7 @@ REG_DIR_REGEX = r"reg_\d{2}__\d{4}_\d{2}_\d{2}_\w"
 
 
 def has_raw_data(t_path=""):
-    """Check if current directory (or that defined by t_path) contains a
+    """Check if current directory (or that defined by t_path contains a
     rawData directory. Returns True if present, False if absent.
     """
     t_path = os.path.join(t_path, RAW_DATA_DIR)
@@ -33,7 +33,7 @@ def has_raw_data(t_path=""):
 
 
 def has_compressed_raw_data(t_path=""):
-    """Check if current directory (or that defined by t_path) has
+    """Check if current directory (or that defined by t_path has
     compressed raw data. Returns True if present, False if absent
     """
     t_path = os.path.join(t_path, "*rawData*.tar.[gb]z")
@@ -41,7 +41,7 @@ def has_compressed_raw_data(t_path=""):
 
 
 def has_recipe_file(t_path=""):
-    """Check if current directory (or that defined by t_path) contains
+    """Check if current directory (or that defined by t_path contains
     a recipe file. Returns True if present, False if absent.
     """
     t_path = os.path.join(t_path, RECIPE_WILDCARD)
@@ -49,7 +49,7 @@ def has_recipe_file(t_path=""):
 
 
 def has_scan_settings(t_path=""):
-    """Check if current directory (or that defined by t_path) contains
+    """Check if current directory (or that defined by t_path contains
     a scanSettings.mat file. Returns True if present, False if absent.
     """
     t_path = os.path.join(t_path, "scanSettings.mat")
@@ -57,7 +57,7 @@ def has_scan_settings(t_path=""):
 
 
 def has_stitched_images_directory(t_path=""):
-    """Check if current directory (or that defined by t_path) contains a
+    """Check if current directory (or that defined by t_path contains a
     stitched image directory Returns True if present, False if absent.
     """
     t_path = os.path.join(t_path, STITCHED_IMAGE_DIR)
@@ -65,7 +65,7 @@ def has_stitched_images_directory(t_path=""):
 
 
 def has_stitched_stacks(t_path=""):
-    """Check if current directory (or that defined by t_path) contains
+    """Check if current directory (or that defined by t_path contains
     stitched tiff stacks. Returns True if present, False if absent.
     """
     t_path = os.path.join(t_path, "./*_chan_0[1-9].tiff")
@@ -73,7 +73,7 @@ def has_stitched_stacks(t_path=""):
 
 
 def has_downsampled_stacks(t_path="", verbose=False):
-    """Check if current directory (or that defined by t_path) contains a
+    """Check if current directory (or that defined by t_path contains a
     downsampled_stacks directory. Returns True if present, False if absent.
     """
 
@@ -105,7 +105,7 @@ def has_uncropped_stitched_images(t_path=""):
     return file_glob_exist(t_path)
 
 
-def is_data_folder(dirToTest=""):
+def is_data_folder(dirToTest="", verbose=False):
     """is directory "dirToTest" a BakingTray data directory?
     i.e. it satisfies the following criteria:
      - contains a recipe YML
@@ -113,6 +113,19 @@ def is_data_folder(dirToTest=""):
      - contains one of: stitchedImages directory, stitched stacks,
                      rawData directory, compressed rawData
     """
+
+    if len(dirToTest) == 0:
+        dirToTest = os.getcwd()
+
+    if not os.path.exists(dirToTest):
+        print("Directory %s does not exist!" % dirToTest)
+        return False
+
+    if verbose:
+        print('Testing if directory "%s" is a valid sample directory.' % dirToTest)
+        print("Directory contents:")
+        print(os.listdir(dirToTest))
+
     if (has_recipe_file(dirToTest) and has_scan_settings(dirToTest)) and (
         has_stitched_stacks(dirToTest)
         or has_stitched_images_directory(dirToTest)
@@ -120,27 +133,62 @@ def is_data_folder(dirToTest=""):
         or has_compressed_raw_data(dirToTest)
     ):
         return True
+
     else:
+        if verbose:
+            print("Test directory is not a data folder:")
+            print("Has recipe: %s" % has_recipe_file(dirToTest))
+            print("Has scan settings: %s" % has_scan_settings(dirToTest))
+            print("Has stitched stacks: %s" % has_stitched_stacks(dirToTest))
+            print(
+                "Has stitched images directory: %s"
+                % has_stitched_images_directory(dirToTest)
+            )
+            print("Has raw data: %s" % has_raw_data(dirToTest))
+            print("Has compressed raw data: %s" % has_compressed_raw_data(dirToTest))
+
         return False
 
 
-def contains_data_folders(dirToTest):
+def contains_data_folders(dirToTest, verbose=False):
     """returns true if dirToTest contains sub-directories that are
     BakingTray data folders.
     """
     subDirs = next(os.walk(dirToTest))[1]
+
     if len(subDirs) == 0:
         return False
+
     for tDir in subDirs:
-        if is_data_folder(os.path.join(dirToTest, tDir)):
+        path_to_test = os.path.join(dirToTest, tDir)
+        if not os.path.exists(path_to_test):
+            print("Directory %s does not exist!" % path_to_test)
+            return False
+
+        if verbose:
+            print('Testing if "%s" is a data folder: ' % path_to_test, end="")
+
+        if is_data_folder(path_to_test):
+            if verbose:
+                print("YES")
             return True
 
+        else:
+            if verbose:
+                print("NO")
+                dir_contents = os.listdir(path_to_test)
+                if len(dir_contents) == 0:
+                    print("Directory is empty")
+                else:
+                    print("Directory contents:")
+                    print(dir_contents)
+
     # If we're here then there are no data-containing subdirs
     return False
 
 
 def available_downsampled_volumes(in_path="", verbose=False):
-    """Check if current directory (or that defined by t_path) contains a ownsampled stacks
+    """Check if current directory (or that defined by t_path contains a ownsampled stacks
     directory and returns a list of dictionaries listing the available downsampled data.
     If none are present returns False.
     """
@@ -151,7 +199,10 @@ def available_downsampled_volumes(in_path="", verbose=False):
     # stacks are called. The following line can have two layers of wildcards.
     # e.g. downsampled_stacks/*_micron/ds_*.txt
     in_path = os.path.join(
-        in_path, DOWNSAMPLED_DIR, DOWNSAMPLED_STACK_SUB_DIR, DOWNSAMPLED_STACK_LOG_FILE
+        in_path,
+        DOWNSAMPLED_DIR,
+        DOWNSAMPLED_STACK_SUB_DIR,
+        DOWNSAMPLED_STACK_LOG_FILE,
     )
     paths_to_downsampled_stacks = glob(in_path)
 
@@ -173,7 +224,6 @@ def read_downsample_log_file(pathToFile=""):
     no data are found in the defined path or multiple paths were supplied.
     """
 
-    print("READING FILE %s" % pathToFile)
     if len(pathToFile) < 1:
         return False
     elif isinstance(pathToFile, list) and len(pathToFile) == 1:
@@ -203,14 +253,13 @@ def read_downsample_log_file(pathToFile=""):
     out["acqdate"] = s.group(1)
 
     # Get the voxel size from the directory name
-    s = re.search(r".*/(\d+)_micron/", pathToFile)
+    s = re.search(r".*(\d{3})_micron", pathToFile)
     out["voxelsize"] = int(s.group(1))
 
     # Get the channel index from the file name
     s = re.search(r".*_ch(0\d+)", pathToFile)
     out["channelindex"] = int(s.group(1))
 
-
     # Get the channel friendly name from the file name
     s = re.search(r".*_ch\d+_chan_\d_(.*)\.t", pathToFile)
     if s is not None:
@@ -261,7 +310,9 @@ def query_yes_no(question, default="yes"):
         elif choice in valid:
             return valid[choice]
         else:
-            sys.stdout.write("Please respond with 'yes' or 'no' " "(or 'y' or 'n').\n")
+            sys.stdout.write(
+                "Please respond with 'yes' or 'no' " "(or 'y' or 'n').\n"
+            )
 
 
 def in_tmux_session():
@@ -318,7 +369,9 @@ def get_dir_size_in_GB(t_path, fast_raw_data=False):
     size_in_bytes = sum(f.stat().st_size for f in t_path if f.is_file())
 
     if fast_raw_data:
-        size_in_bytes = size_in_bytes * 10  # Because we measured every 10th directory
+        size_in_bytes = (
+            size_in_bytes * 10
+        )  # Because we measured every 10th directory
         size_in_bytes = size_in_bytes * 1.03  # Because we skipped some directories
 
     return size_in_bytes / 1024**3
@@ -481,7 +534,8 @@ def make_reg_dir(simulate=False):
 
 
 def make_log_dir():
-    print('hello')
+    print("hello")
+
 
 def increment_char(t_char, increment_by=1):
     """
