@@ -30,6 +30,7 @@ import sys
 import subprocess
 from textwrap import dedent  # To remove common leading white-space
 from btpytools import tools
+from termcolor import colored
 
 
 def cli_parser():
@@ -42,45 +43,46 @@ def cli_parser():
         prog="transferToServer",
         description=dedent(
             """\
-                            Transfer BrainSaw data to a server mounted on the local machine
+        Transfer BrainSaw data to a server mounted on the local machine
 
-                            This function is a wrapper round rsync and is used for copying BakingTray
-                            data to a server. It automatically does not copy uncompressed raw data or
-                            the un-cropped stacks directory.
+        This function is a wrapper round rsync and is used for copying BakingTray
+        data to a server. It automatically does not copy uncompressed raw data or
+        the un-cropped stacks directory.
 
-                            Input arguments
-                            - one or more paths to local directories which are to be copied
-                            - the last path is the destination.
+        Input arguments
+        - one or more paths to local directories which are to be copied
+        - the last path is the destination.
 
 
-                            Usage examples:
+        Usage examples:
 
-                            1. Transfer one sample plus any compressed raw data:
-                               $ transferToServer ./XY_123 /mnt/datastor/user/path/
+        1. Transfer one sample plus any compressed raw data:
+           $ transferToServer ./XY_123 /mnt/datastor/
 
-                            2. Transfer a directory containing two samples (after cropping) plus any compressed raw data.
-                               You will be prompted whether you want the source data to be copied in the enclosing directory.
-                               $ transferToServer ./USER_sampleA_sampleB/ /mnt/datastor/user/path/
+        2. Transfer a directory containing two samples (after cropping) plus any
+           compressed raw data. You will be prompted whether you want the source data
+           to be copied in the enclosing directory.
+           $ transferToServer ./dataA_B/ /mnt/server/
 
-                               Note, this is the same as doing:
-                               $ transferToServer ./USER_sampleA_sampleB/sample1 ./USER_sampleA_sampleB/sample2 ./USER_sampleA_sampleB/rawData.tar.bz /mnt/datastor/user/path/
+           Note, this is the same as doing:
+           $ transferToServer ./dataA_B/sampA ./dataA_B/sampB ./dataA_B/rawData.tar.bz /mnt/server/
 
-                            3. Simulate the transfer of one sample
-                               $ transferToServer ./XY_123 /mnt/datastor/user/path/ -s
+        3. Simulate the transfer of one sample
+           $ transferToServer ./XY_123 /mnt/datastor/ -s
 
-                            4. Run with different rsync flags
-                               $ transferToServer ./XY_123 /mnt/datastor/user/path/ -r rv
+        4. Run with different rsync flags
+           $ transferToServer ./XY_123 /mnt/datastor/ -r rv
 
-                           """
+        """
         ),
         epilog=dedent(
             """\
-                        Notes
-                        If you have signed in via SSH and aren't in a tmux session, the function
-                        asks for confirmation before continuing. If your ssh session breaks off
-                        for some reason, then compression will fail. tmux is therefore recommended
-                        in this situation.
-                      """
+                Notes
+                If you have signed in via SSH and aren't in a tmux session, the function
+                asks for confirmation before continuing. If your ssh session breaks off
+                for some reason, then compression will fail. tmux is therefore recommended
+                in this situation.
+            """
         ),
     )
 
@@ -107,7 +109,10 @@ def cli_parser():
         required=False,
         default="av",
         type=str,
-        help='If supplied, this rsync flag is used. Default is "av". Other reasonable options include "rv".',
+        help=(
+            "If supplied, this rsync flag is used. "
+            'Default is "av". Other reasonable options include "rv".'
+        ),
     )
 
     return parser
@@ -159,11 +164,10 @@ def user_specified_cropped_directories_individually(source_dirs, verbose=False):
 
     # If the list is only one directory long (or is a string) then we still need to check if it
     # is a cropped directory before deciding for sure wether to return True or False.
-    if (
-        isinstance(source_dirs, str)
-        or isinstance(source_dirs, list)
-        and len(source_dirs) == 1
-    ):
+    if isinstance(source_dirs, list) and len(source_dirs) == 1:
+        source_dirs = source_dirs[0]
+
+    if isinstance(source_dirs, str):
         if tools.has_compressed_raw_data(os.path.split(source_dirs)[0]):
             # Parent directory contains a compressed archive. This makes it
             # likely this was a cropped directory and that the user could
@@ -222,22 +226,59 @@ def user_specified_cropped_directories_individually(source_dirs, verbose=False):
     return True
 
 
-def dir_list_contains_compressed_archive(source_dirs):
+def dir_list_contains_compressed_archive(source_dirs, dir_root="", verbose=False):
     """
     Does the directory list in source_dirs contain at least one compressed raw data archive? The
-    lack of a compressed archive in this list does not meant the compressed raw data are not going
+    lack of a compressed archive in this list does not mean the compressed raw data are not going
     to be sent. It just reflects whether or not the user has explicitly asked to send the data.
 
     This function is used in conjunction with others to determine whether there is a chance that
     the user is accidentally failing to back up compressed raw data.
 
+    Function looks for a tar.bz or tar.gz archive
+
     Inputs:
     source_dirs - a list of source directories
+    dir_root -  Optional. Empty by default. If present, dir_root restricts the search to only dirs
+                that match. See below for examples.
 
     Outputs
     True means the directory list in source_dirs contains a raw data archive. False otherwise.
+
+    Examples
+    source_dirs = ['./sample_dir/sample1', './sample_dir/sample2']
+    dir_list_contains_compressed_archive(source_dirs)  # Returns False
+
+
+    source_dirs = ['./sample_dir/sample1', './sample_dir/sample2', 'sample_dir/rawData.tar.bz']
+    dir_list_contains_compressed_archive(source_dirs)  # Returns True
+
+
+    source_dirs = ['./sample_dir/sample1', './sample_dir/sample2', 'OTHER_DIR/rawData.tar.bz']
+    dir_list_contains_compressed_archive(source_dirs)  # Returns True
+
+
+    source_dirs = ['./sample_dir/sample1', './sample_dir/sample2', 'OTHER_DIR/rawData.tar.bz']
+    dir_list_contains_compressed_archive(source_dirs, './sample_dir'')  # Returns False
     """
 
+    # Filter list if needed. This will remove everything that does not match dir_root
+    if len(source_dirs) == 0:
+        return False
+
+    if verbose:
+        print("Searching list for compressed data archive:")
+        print(source_dirs)
+
+    if len(dir_root) > 0:
+        source_dirs = [i for i in source_dirs if i.startswith(dir_root)]
+
+    if len(source_dirs) == 0:
+        print(
+            "dir_list_contains_compressed_archive -- Source directories have all been removed. Odd"
+        )
+        return False
+
     compressed_archives = [
         x
         for x in source_dirs
@@ -261,29 +302,58 @@ def issue_warning_if_compressed_data_will_not_be_sent(source_dirs, verbose=False
         if verbose:
             print("Directories not specified individually")
 
-        return False
+        return False  # False, nothing is wrong
 
-    # If we are here, there are indivually specified directories
+    # If we are here, there are individually specified directories
     if verbose:
         print("Individually specified directories found")
 
     # If the user specified the directories individually we are still "safe" so long as either
     # a) They included the compressed archive in the transfer list (source_dirs).
-    # b) There is no compressed archive (meaning the user does not want to back up raw data)
-    if dir_list_contains_compressed_archive(source_dirs):
-        if verbose:
-            print("List contains a compressed archive")
-        return False
+    # b) There is no compressed archive (so the user probably does not want to back up raw data)
+    # Go through each directory in the list and confirm the above
 
-    # Go through each directory in the list. If it is The following
-    dir_to_test = os.path.split(source_dirs[0])[0]
-    if not tools.has_compressed_raw_data(dir_to_test):
-        if verbose:
-            print("No raw data archive found in directory %s" % dir_to_test)
-        return False
+    return_state = (
+        False  # False, nothing is wrong (unless the loop below modifies this)
+    )
+    for t_dir in source_dirs:
+        if not os.path.isdir(t_dir):
+            # Skip if this is not a directory (e.g. it's a raw data archive)
+            if verbose:
+                print("%s is not a directory: skipping it" % t_dir)
+            continue
 
-    # If we are here, there could be compressed raw data that are not being sent
-    return True
+        print(t_dir, end="")
+
+        parent_dir = os.path.split(t_dir)[0]  # convenience
+
+        if tools.has_compressed_raw_data(t_dir):
+            # If true the directory itself contains compressed data.
+            print(colored(" has compressed raw data", "green"))
+        elif dir_list_contains_compressed_archive(source_dirs, parent_dir):
+            # If true, the directory is a split sample and the user has also specified that
+            # they want the raw data to be sent.
+            print(
+                colored(
+                    " is a split sample and compressed raw data are being sent",
+                    "green",
+                )
+            )
+        elif not dir_list_contains_compressed_archive(
+            source_dirs, parent_dir
+        ) and tools.has_compressed_raw_data(parent_dir):
+            # This sample contains no raw data directory within it, the user did not specify
+            # raw data but there *is* raw data in its parent directory. This means the user
+            # intended to send the data but is not doing so.
+            print(
+                colored(
+                    " is a split sample with raw data that are not being sent!",
+                    "red",
+                )
+            )
+            return_state = True  # We have a problem
+
+    return return_state
 
 
 def remove_single_samples_from_list(source_dirs, verbose=False):
@@ -293,7 +363,7 @@ def remove_single_samples_from_list(source_dirs, verbose=False):
     """
 
     if not isinstance(source_dirs, list):
-        return
+        return False
 
     # Remove everything from the list that is not a directory
     source_dirs = [x for x in source_dirs if os.path.isdir(x)]
@@ -334,7 +404,8 @@ def main():
 
     if len(args.paths) < 2:
         print(
-            "\n\n ERROR: transferToServer requires at least one local path to copy and a destination\n"
+            "\n\n ERROR: "
+            "transferToServer requires at least one local path to copy and a destination\n"
         )
         print(' See "transferToServer -h"\n')
         sys.exit()
@@ -355,12 +426,12 @@ def main():
         sys.exit()
 
     # Remove trailing slash from data directories that don't contain data sub-directories
-    for ii, t_dir in enumerate(source_dirs):
+    for _ii, t_dir in enumerate(source_dirs):
         if tools.is_data_folder(t_dir) and not tools.contains_data_folders(t_dir):
             # If here, tDIR is a sample folder without sub-folders. If there is a
             # trailing slash then we should delete it. Always.
             if t_dir[-1] == os.path.sep:
-                source_dirs[ii] = t_dir[0:-1]
+                source_dirs[_ii] = t_dir[0:-1]
 
         elif tools.contains_data_folders(t_dir):
             # If here, tDIR contains sub-folders which are sample folders. Thus is likely
@@ -368,7 +439,7 @@ def main():
             # user the option to add it back, copying the *contents* to the destination
             # rather than in the enclosing folder.
             if t_dir[-1] == os.path.sep:
-                source_dirs[ii] = t_dir[0:-1]
+                source_dirs[_ii] = t_dir[0:-1]
 
             print('\nDirectory "%s" contains multiple samples.' % t_dir)
             print(
@@ -377,13 +448,13 @@ def main():
             )
             if not tools.query_yes_no(""):
                 # Add trailing slash, if user does not want to keep enclosing folder.
-                source_dirs[ii] = source_dirs[ii] + os.path.sep
+                source_dirs[_ii] = source_dirs[_ii] + os.path.sep
 
     print("")
 
     # Check whether any of the directories we plan to copy already exist at the destination
     safe_to_copy = True
-    for ii, t_dir in enumerate(source_dirs):
+    for _ii, t_dir in enumerate(source_dirs):
 
         if t_dir[-1] != os.path.sep:
             # Look for this directory at the destination
@@ -391,20 +462,22 @@ def main():
             if os.path.exists(destination_path):
                 safe_to_copy = False
                 print(
-                    '===>>> WARNING!! "%s" already exists in "%s"!! Proceeding will over-write its contents <===='
+                    '===>>> WARNING!! "%s" already exists in "%s"!! '
+                    "Proceeding will over-write its contents <===="
                     % (t_dir, destination_dir)
                 )
         else:
             # Look for the *contents* of this directory at the destination
             dir_contents = os.listdir(t_dir)
-            for jj, sub_dir in enumerate(dir_contents):
+            for _jj, sub_dir in enumerate(dir_contents):
                 if sub_dir == "rawData" or "_DELETE_ME" in sub_dir:
                     continue
                 destination_path = os.path.join(destination_dir, sub_dir)
                 if os.path.exists(destination_path):
                     safe_to_copy = False
                     print(
-                        '===>>> WARNING!! "%s" already exists in "%s"!! Proceeding will over-write its contents <===='
+                        '===>>> WARNING!! "%s" already exists in "%s"!! '
+                        "Proceeding will over-write its contents <===="
                         % (sub_dir, destination_dir)
                     )
 
@@ -413,14 +486,27 @@ def main():
         if not tools.query_yes_no(""):
             sys.exit()
 
+    # Check whether the user is maybe failing to copy raw data
+
+    if issue_warning_if_compressed_data_will_not_be_sent(source_dirs):
+        print(
+            "\nYou have specified directories individually and have omitted to "
+            "ask for existing compressed raw data to be sent!"
+        )
+        print("Please see the readme at: https://pypi.org/project/btpytools/")
+        if not tools.query_yes_no(
+            "Are you sure you want to continue?", default="no"
+        ):
+            sys.exit()
+
     # Ask for confirmation before starting
     print("\nPerform the following transfer?")
-    for ii, t_dir in enumerate(source_dirs):
+    for _ii, t_dir in enumerate(source_dirs):
         if t_dir[-1] != os.path.sep:
             print('Copy directory "%s" to location "%s"' % (t_dir, destination_dir))
         else:
             dir_contents = os.listdir(t_dir)
-            for jj, sub_contents in enumerate(dir_contents):
+            for _jj, sub_contents in enumerate(dir_contents):
                 if sub_contents == "rawData" or sub_contents.endswith("_DELETE_ME"):
                     pass
                 else:
@@ -433,34 +519,47 @@ def main():
         destination_dir,
     )
 
-    print("Using command %s" % cmd)
+    print("")
+
     if not tools.query_yes_no(""):
         sys.exit()
 
-
     # Start the transfer and return standard output to the CLI
     os.system(cmd)
 
     # There are rare cases where the transfer of individual files failed and they became corrupt.
     # Here we see empty files in the destination, whereas in the source they are OK. Re-running the
     # transfer will fix these instances. So we do that here.
-    print('\nLooking for corrupted files in destination...\n')
+    print("\nLooking for corrupted files in destination...\n")
     max_retries = 10
     pass_number = 1
+
+    # Alter the rsync command to add more information
+    cmd = cmd.replace("rsync -", "rsync -i")
+
     while True:
         out = subprocess.check_output(cmd, shell=True)
 
-        #If the second line is empty then everything has been transfered OK
-        if len(out.decode().split("\n")[1]) == 0:
-            print('Good! There are no corrupt empty files on the server.')
+        # Convert to a string
+        out = out.decode()
+
+        # If there are no ">" with -i then nothing was sent
+        num_transfered_files = out.count(">")
+        if num_transfered_files == 0:
+            print("Good! There are no corrupt empty files on the server.")
             break
         else:
-            print('Corrected corrupt files at destination. Checking again...\n')
+            print(
+                "Corrected %d corrupt files at destination. Checking again...\n"
+                % num_transfered_files
+            )
 
         pass_number += 1
         if pass_number > max_retries:
-            print('After %d attempts there still seem to be corrupt files on the server!' %
-                  max_retries)
+            print(
+                "After %d attempts there still seem to be corrupt files on the server!"
+                % max_retries
+            )
             break
 
 
