@@ -1,6 +1,6 @@
 # Quick shell script to run common tasks
 
-pytest-3 tests/tests/basic.py
+pytest
 python3 -m black ./
 python3 setup.py sdist
 
